@@ -25,9 +25,30 @@ class BobsledClient:
             base_url + "/signin-with-password",
             data=self.credentials,
             params=params)
+
         if r.status_code != 204:
             handle_errors(r)
 
+        params = {
+            "_data": "routes/__auth/shares"
+        }
+
+        r = self.s.get(
+            base_url + "/shares",
+            params=params
+        )
+        
+        if r.status_code != 200:
+            handle_errors(r)
+
+        # Does this actually work?
+        # What if you are normally a consumer, but is a provider on the share?
+        role = r.json()["userProviderMembership"]["role"]
+        if role == "member":
+            self.role = "/provider"
+        else:
+            self.role = "/consumer"
+
     def list_shares(self):
         """Returns a list of share_ids that can be used with get_share
 
@@ -75,22 +96,23 @@ class BobsledClient:
             handle_errors(r)
         header_str = r.headers["x-remix-redirect"]
         share_id = header_str[8:].split("/")[0]
-        return self.Share(share_id, self.s, self.base_url)
+        return self.Share(share_id, self.s, self.base_url, self.role)
 
 
     class Share:
         """
         This class represents a share, and should only be acquired by the user through calling get_share or create_share on a BobsledClient
         """
-        def __init__(self, share_id, session, base_url):
+        def __init__(self, share_id, session, base_url, role):   
             self.share_id = share_id
             self.s = session
             self.base_url = base_url
-            
+            self.role = role
+
             params = {"_data": "routes/__auth/shares.$shareId/$role"}
             
             r = self.s.get(
-                self.base_url + "/shares/" + self.share_id + "/provider",
+                self.base_url + "/shares/" + self.share_id + self.role,
                 params=params
             )
             
@@ -103,13 +125,13 @@ class BobsledClient:
         def get_share_information(self):
             """Retrieves and returns full information on the share
             
-            :calls: `GET /shares/{share_id}`
+            :calls: `GET /shares/{share_id}/{role}`
             :return: Dictionary containing full information on the share
             """            
             params = {"_data": "routes/__auth/shares.$shareId/$role"}
             
             r = self.s.get(
-                self.base_url + "/shares/" + self.share_id + "/provider",
+                self.base_url + "/shares/" + self.share_id + self.role,
                 params=params
             )
             
@@ -121,7 +143,7 @@ class BobsledClient:
         def archive(self):
             """Archives current share
             
-            :calls; `POST /shares/{share_id}`
+            :calls; `POST /shares/{share_id}/{role}`
             """            
             
             params = {
@@ -133,7 +155,7 @@ class BobsledClient:
             }
             
             r = self.s.post(
-                self.base_url + "/shares/" + self.share_id + "/provider",
+                self.base_url + "/shares/" + self.share_id + self.role,
                 params=params,
                 data=data
             )
@@ -185,7 +207,7 @@ class BobsledClient:
         def set_overview(self, name, description):
             """Sets overview text of the share
             
-            :calls: `GET /shares/{share_id}/overview`
+            :calls: `GET /shares/{share_id}/{role}/overview`
             """
         
             data = {
@@ -198,7 +220,7 @@ class BobsledClient:
             }
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/overview",
+                self.role + "/overview",
                 data=data,
                 params=params)
             if r.status_code != 204:
@@ -207,7 +229,7 @@ class BobsledClient:
         def get_source_locations(self):
             """Retrieves and returns locations that can be used in set_source_location
             
-            :calls: `GET /shares/{share_id}/source`
+            :calls: `GET /shares/{share_id}/{role}/source`
             :return: list of locations 
             """
             
@@ -216,7 +238,7 @@ class BobsledClient:
             }
             r = self.s.get(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/source",
+                self.role + "/source",
                 params=params)
             if r.status_code != 200:
                 handle_errors(r)
@@ -226,7 +248,7 @@ class BobsledClient:
         def set_source_location(self, location_id):
             """Set the source of the share to location_id
 
-            :calls: `POST /shares/{share_id}/source`
+            :calls: `POST /shares/{share_id}/{role}/source`
             :param location_id: unique identifier of a source container
             """            
             data = {"locationIdJs": location_id,
@@ -237,7 +259,7 @@ class BobsledClient:
             }
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/source",
+                self.role + "/source",
                 data=data,
                 params=params)
             if r.status_code != 204:
@@ -246,7 +268,7 @@ class BobsledClient:
         def get_destination_locations(self):
             """Get destination locations that can be used in set_destination_location
 
-            :calls: `GET /shares/{share_id}/destination/new`
+            :calls: `GET /shares/{share_id}/{role}/destination/new`
             :return: something, a list or dictionary of locations, undecided
             """            
             
@@ -256,7 +278,7 @@ class BobsledClient:
             
             r = self.s.get(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/destination/new",
+                self.role + "/destination/new",
                 params=params
             )
             if r.status_code != 200:
@@ -266,7 +288,7 @@ class BobsledClient:
         def set_destination_location(self, cloud, region):
             """Sets destination location of this share to given cloud and location_id (region?)
 
-            :calls: `POST /shares/{share_id}/destination/new`
+            :calls: `POST /shares/{share_id}/{role}/destination/new`
             :param cloud: cloud provider (e.g. AWS)
             :param region: id of a region inside the cloud
             """         
@@ -277,7 +299,7 @@ class BobsledClient:
             }
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/destination/new",
+                self.role + "/destination/new",
                 data=data,
                 params=params)
             if r.status_code != 204:
@@ -287,7 +309,8 @@ class BobsledClient:
             """Returns flattened contents of all files that were last modified after time in source location
 
             :calls: `GET /shares/{share_id}/loadCloudData`
-            :param time: folder path (with format `/top_level_folder/another_folder/`) and UNIX timestamp in seconds
+            :param path: folder path (with format `/top_level_folder/another_folder/`) indicating which folder to begin search from (default is root)
+            :param time: UNIX timestamp in seconds
             :return: list of file paths, total size of files
             """            
             params = {
@@ -369,7 +392,7 @@ class BobsledClient:
         def create_delivery(self, selection, size = 1000, overwriteMode = False):
             """Creates and returns a Delivery object given selection of file paths
 
-            :calls: `POST /shares/{share_id}/delivery`
+            :calls: `POST /shares/{share_id}/{role}/delivery`
             :param selection: file paths for files in the source container to be included in this delivery
             :param size: total size of files in this delivery
             :param overwriteMode: boolean indicating whether overwriteMode is on (True) or off (False)
@@ -384,7 +407,7 @@ class BobsledClient:
             
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/delivery",
+                self.role + "/delivery",
                 data=data,
                 allow_redirects=False)
             
@@ -404,7 +427,7 @@ class BobsledClient:
         def get_team(self):
             """Returns team members
 
-            :calls: `GET /shares/{share_id}/team`
+            :calls: `GET /shares/{share_id}/{role}/team`
             :return: dictionary representing team members
             """            
             params = {
@@ -413,7 +436,7 @@ class BobsledClient:
             
             r = self.s.get(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/team",
+                self.role + "/team",
                 params=params)
             if r.status_code != 200:
                 handle_errors(r)
@@ -422,20 +445,19 @@ class BobsledClient:
         def add_consumer(self, consumer_email):
             """Adds a consumer by given email
 
-            :calls: `POST /shares/{share_id}/team`
+            :calls: `POST /shares/{share_id}/{role}/team`
             :param consumer_email: email address of the consumer to be added
             """            
             data = {
                 "email": consumer_email,
-                "role": "consumer",
-                "actionType": "addUserToShare"
+                "actionType": "addConsumerToShare"
             }
             params = {
                 "_data": "routes/__auth/shares.$shareId/$role/team"
             }
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/team",
+                self.role + "/team",
                 data=data,
                 params=params)
             if r.status_code != 200:
@@ -444,12 +466,11 @@ class BobsledClient:
         def add_consumers(self, consumer_email_list):
             """Adds all emails provided to consumers
 
-            :calls: `POST /shares/{share_id}/team`
+            :calls: `POST /shares/{share_id}/{role}/team`
             :param consumer_email_list: list of email addresses of the consumers to be added
             """            
             data = {
-                "role": "consumer",
-                "actionType": "addUserToShare"
+                "actionType": "addConsumerToShare"
             }
             params = {
                 "_data": "routes/__auth/shares.$shareId/$role/team"
@@ -458,7 +479,7 @@ class BobsledClient:
                 data["email"] = email
                 r = self.s.post(
                     self.base_url + "/shares/" + self.share_id +
-                    "/provider/team",
+                    self.role + "/team",
                     data=data,
                     params=params)
                 if r.status_code != 200:
@@ -481,7 +502,7 @@ class BobsledClient:
             
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/team",
+                self.role + "/team",
                 data=data,
                 params=params
             )
@@ -501,7 +522,7 @@ class BobsledClient:
             }
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
-                "/provider/destination/edit",
+                self.role + "destination/edit",
                 data=data)
             if r.status_code != 204 and r.status_code != 200:
                 handle_errors(r)
@@ -539,6 +560,7 @@ class BobsledClient:
                 self.share_id = share.share_id
                 self.s = share.s
                 self.base_url = share.base_url
+                self.role = share.role
 
             def __str__(self):
                 return self.__repr__()
@@ -549,7 +571,7 @@ class BobsledClient:
             def deliver_delivery(self):
                 """Delivers this Delivery
                 
-                :calls: `POST /shares/{share_id}`
+                :calls: `POST /shares/{share_id}/{role}`
                 """                
                 data = {
                     "deliverDeliveryId": self.delivery_id,
@@ -559,7 +581,7 @@ class BobsledClient:
                     "_data": "routes/__auth/shares.$shareId/$role"
                 }
                 r = self.s.post(
-                    self.base_url + "/shares/" + self.share_id + "/provider",
+                    self.base_url + "/shares/" + self.share_id + self.role,
                     data=data,
                     params=params)
                 if not (200 <= r.status_code < 300):
@@ -579,7 +601,7 @@ class BobsledClient:
             def access(self):
                 """Returns the URL to access this delivery
 
-                :calls: `GET /shares/{share_id}/deliveries/{delivery_id}/access`
+                :calls: `GET /shares/{share_id}/{role}/deliveries/{delivery_id}/access`
                 :return: URL where deliveries can be accessed
                 """                
                 
@@ -588,7 +610,7 @@ class BobsledClient:
                 }
                 
                 r = self.s.get(
-                    self.base_url + "/shares/" + self.share_id + "/provider/deliveries/" + self.delivery_id + "/access",
+                    self.base_url + "/shares/" + self.share_id + self.role + "/deliveries/" + self.delivery_id + "/access",
                     params=params)
                 
                 if r.status_code != 200:
